@@ -47,6 +47,9 @@ class GitCloneHandler(GitHandler):
         response = await self.git.clone(
             data["current_path"], data["clone_url"], data.get("auth", None)
         )
+
+        if response["code"] != 0:
+            self.set_status(500)
         self.finish(json.dumps(response))
 
 
@@ -72,6 +75,7 @@ class GitAllHistoryHandler(GitHandler):
 
         show_top_level = await self.git.show_top_level(current_path)
         if show_top_level["code"] != 0:
+            self.set_status(500)
             self.finish(json.dumps(show_top_level))
         else:
             branch = await self.git.branch(current_path)
@@ -103,6 +107,9 @@ class GitShowTopLevelHandler(GitHandler):
         """
         current_path = self.get_json_body()["current_path"]
         result = await self.git.show_top_level(current_path)
+
+        if result["code"] != 0:
+            self.set_status(500)
         self.finish(json.dumps(result))
 
 
@@ -121,6 +128,27 @@ class GitShowPrefixHandler(GitHandler):
         """
         current_path = self.get_json_body()["current_path"]
         result = await self.git.show_prefix(current_path)
+
+        if result["code"] != 0:
+            self.set_status(500)
+        self.finish(json.dumps(result))
+
+
+class GitFetchHandler(GitHandler):
+    """
+    Handler for 'git fetch'
+    """
+
+    @web.authenticated
+    async def post(self):
+        """
+        POST request handler, fetch from remotes.
+        """
+        current_path = self.get_json_body()["current_path"]
+        result = await self.git.fetch(current_path)
+
+        if result["code"] != 0:
+            self.set_status(500)
         self.finish(json.dumps(result))
 
 
@@ -136,6 +164,9 @@ class GitStatusHandler(GitHandler):
         """
         current_path = self.get_json_body()["current_path"]
         result = await self.git.status(current_path)
+
+        if result["code"] != 0:
+            self.set_status(500)
         self.finish(json.dumps(result))
 
 
@@ -155,6 +186,9 @@ class GitLogHandler(GitHandler):
         current_path = body["current_path"]
         history_count = body.get("history_count", 25)
         result = await self.git.log(current_path, history_count)
+
+        if result["code"] != 0:
+            self.set_status(500)
         self.finish(json.dumps(result))
 
 
@@ -194,6 +228,9 @@ class GitDiffHandler(GitHandler):
         """
         top_repo_path = self.get_json_body()["top_repo_path"]
         my_output = await self.git.diff(top_repo_path)
+
+        if my_output["code"] != 0:
+            self.set_status(500)
         self.finish(my_output)
 
 
@@ -215,6 +252,31 @@ class GitBranchHandler(GitHandler):
         self.finish(json.dumps(result))
 
 
+class GitBranchDeleteHandler(GitHandler):
+    """
+    Handler for 'git branch -D <branch>'
+    """
+
+    @web.authenticated
+    async def post(self):
+        """
+        POST request handler, delete branch in current repository.
+
+        Body: {
+            "current_path": Git repository path relatively to the server root,
+            "branch": Branch name to be deleted
+        }
+        """
+        data = self.get_json_body()
+        result = await self.git.branch_delete(data["current_path"], data["branch"])
+
+        if result["code"] != 0:
+            self.set_status(500)
+            self.finish(json.dumps(result))
+        else:
+            self.set_status(204)
+
+
 class GitAddHandler(GitHandler):
     """
     Handler for git add <filename>'.
@@ -556,6 +618,9 @@ class GitChangedFilesHandler(GitHandler):
     @web.authenticated
     async def post(self):
         body = await self.git.changed_files(**self.get_json_body())
+
+        if body["code"] != 0:
+            self.set_status(500)
         self.finish(json.dumps(body))
 
 
@@ -725,6 +790,7 @@ def setup_handlers(web_app):
         ("/git/add_all_untracked", GitAddAllUntrackedHandler),
         ("/git/all_history", GitAllHistoryHandler),
         ("/git/branch", GitBranchHandler),
+        ("/git/branch/delete", GitBranchDeleteHandler),
         ("/git/changed_files", GitChangedFilesHandler),
         ("/git/checkout", GitCheckoutHandler),
         ("/git/clone", GitCloneHandler),
@@ -739,6 +805,7 @@ def setup_handlers(web_app):
         ("/git/pull", GitPullHandler),
         ("/git/push", GitPushHandler),
         ("/git/remote/add", GitRemoteAddHandler),
+        ("/git/remote/fetch", GitFetchHandler),
         ("/git/reset", GitResetHandler),
         ("/git/reset_to_commit", GitResetToCommitHandler),
         ("/git/server_root", GitServerRootHandler),
